@@ -12,7 +12,12 @@ use Mouse;
 has last_send   => is => 'rw', isa => 'Str';
 has last_recv   => is => 'rw', isa => 'Str';
 
-sub send { $_[0]->last_send( $_[1] ) }
+sub send {
+    use bytes;
+    $_[0]->last_send( $_[1] );
+    return length $_[1];
+}
+
 sub recv {
     use bytes;
 
@@ -20,7 +25,7 @@ sub recv {
     $_[1]       = substr $last, 0, $_[2], '';
     $_[0]->last_recv($last);
 
-    return;
+    return '';
 }
 
 1;
